@@ -16,7 +16,7 @@ use experimental 'signatures';
 use Future::AsyncAwait;
 use Object::Pad;
 
-class Sys::Async::Virt::Connection::Factory v0.5.2;
+class Sys::Async::Virt::Connection::Factory v0.6.0;
 
 use Carp qw(croak);
 use Log::Any qw($log);
@@ -25,8 +25,8 @@ use Protocol::Sys::Virt::URI; # imports 'parse_url'
 our @default_drivers = (
     { transport => '', class => 'Local', host => 0 },
     { transport => 'unix', class => 'Local', host => 0 },
-    # { transport => '', class => 'TCP', host => 1 },
-    # { transport => 'tls', class => 'TCP' },
+    { transport => '', class => 'TLS', host => 1 },
+    { transport => 'tls', class => 'TLS' },
     { transport => 'tcp', class => 'TCP' },
     { transport => 'ext', class => 'Process' },
     { transport => 'ssh', class => 'SSH' },
@@ -82,7 +82,7 @@ Sys::Async::Virt::Connection::Factory - Class for
 
 =head1 VERSION
 
-v0.5.2
+v0.6.0
 
 =head1 SYNOPSIS
 
@@ -150,7 +150,8 @@ C<+YourPackage::Local> resolves to C<YourPackage::Local>.
 
 =back
 
-The default value maps the following transports: C<''>, C<unix>, C<ext> and C<ssh>.
+The default value maps the following transports: C<''>, C<unix>, C<ext>,
+C<tcp>, C<tls> and C<ssh>.
 
 =back
 
