@@ -16,7 +16,7 @@ use experimental 'signatures';
 use Future::AsyncAwait;
 use Object::Pad ':experimental(inherit_field)';
 
-class Sys::Async::Virt::Connection::TCP v0.5.2;
+class Sys::Async::Virt::Connection::TCP v0.6.0;
 
 inherit Sys::Async::Virt::Connection '$_in', '$_out';
 
@@ -47,6 +47,10 @@ method _set_out($out) {
 
 ###
 
+method _default_port() {
+    return 16509;
+}
+
 async method close() {
     # Work around for Future::IO which doesn't
     # like handles being closed when there are
@@ -67,7 +71,7 @@ async method connect() {
     if ($use_async_resolver) {
         my ($address) = await Future::IO::Resolver->getaddrinfo(
             host => $components{host},
-            service => ($components{port} // 16509),
+            service => ($components{port} // $self->_default_port),
             socktype => SOCK_STREAM,
             );
         socket( $_socket,
@@ -80,7 +84,7 @@ async method connect() {
     else {
         my ($err, @addresses) = IO::Socket::IP::getaddrinfo(
             $components{host},
-            ($components{port} // 16509),
+            ($components{port} // $self->_default_port),
             { socktype => SOCK_STREAM }
             );
         die $err if $err;
@@ -88,7 +92,8 @@ async method connect() {
         $_socket = IO::Socket::IP->new(
             Type => SOCK_STREAM,
             PeerAddrInfo => \@addresses,
-            );
+            )
+            or die "Failed to connect socket: $!";
     }
 
     $_in = $_out = $_socket;
@@ -109,7 +114,7 @@ Sys::Async::Virt::Connection::TCP - Connection to LibVirt server over TCP socket
 
 =head1 VERSION
 
-v0.5.2
+v0.6.0
 
 =head1 SYNOPSIS
 
